@@ -88,6 +88,7 @@ void on_preview_configure_event (GtkWidget *drawing_area,
 				 gpointer data);
 void on_ok_button_clicked (GtkWidget *widget, gpointer data);
 void on_cancel_button_clicked (GtkWidget *widget, gpointer data);
+void on_help_button_clicked (GtkWidget *widget, gpointer data);
 int on_toplevel_key_press_event (GtkWidget *widget, GdkEventKey *key);
 
 /* some local prototypes */
@@ -192,6 +193,7 @@ nibble_on_file (const char *file)
 {
 	GtkWidget *dialog;
 	FILE *fp;
+	mode_t old_mask;
 
 	if (access (file, F_OK) == 0) {
 		dialog = gtk_message_dialog_new
@@ -206,6 +208,9 @@ nibble_on_file (const char *file)
 			return NULL;
 		}
 	}
+
+	old_mask = umask(077);
+
 	fp = fopen (file, "w");
 	if (fp == NULL) {
 		dialog = gtk_message_dialog_new
@@ -216,11 +221,14 @@ nibble_on_file (const char *file)
 			 _("Unable to create the file:\n"
 			   "\"%s\"\n"
 			   "Please check your permissions of "
-			   "the parent directory"), file);
+			   "the parent directory"), file ? file : "(null)");
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
+
+		umask(old_mask);
 		return NULL;
 	}
+	umask(old_mask);
 	return fp;
 }
 
@@ -228,14 +236,14 @@ static gboolean
 save_to_file (FILE *fp, const gchar *file, gboolean gui_errors)
 {
 	GtkWidget *dialog;
-	char *error;
+	char *error = NULL;
 
 	if (fp == NULL) {
 		fp = nibble_on_file (file);
 	}
 
 	if ( ! save_to_file_internal (fp, file, &error)) {
-		if (gui_errors) {
+		if (gui_errors && error) {
 			dialog = gtk_message_dialog_new
 				(GTK_WINDOW (toplevel),
 				 0 /* flags */,
@@ -259,6 +267,7 @@ start_temporary (void)
 {
 	char *dir;
 	char *file = NULL;
+	mode_t old_mask;
 
 	if (temporary_file != NULL) {
 		if (access (temporary_file, F_OK) == 0)
@@ -288,12 +297,14 @@ start_temporary (void)
 			g_free (dir);
 		dir = g_strdup_printf ("/tmp/gnome-panel-screenshot-%d",
 				       rand ());
-	} while (mkdir (dir, 0755) < 0);
+	} while (mkdir (dir, 0700) < 0);
 
 	file = add_file_to_path (dir);
 
 	g_free (dir);
 
+	old_mask = umask(077);
+
 	temporary_pid = fork ();
 
 	if (temporary_pid == 0) {
@@ -313,11 +324,14 @@ start_temporary (void)
 		    ! save_to_file (fp, file, TRUE)) {
 			g_free (file);
 			temporary_pid = 0;
+
+			umask(old_mask);
 			return;
 		}
 		temporary_pid = 0;
 	}
 
+	umask(old_mask);
 	temporary_file = file;
 }
 
@@ -694,8 +708,6 @@ gimme_file (const char *filename)
 		fclose (fp);
 
 		if (rename (temporary_file, filename) == 0) {
-			g_free (temporary_file);
-			temporary_file = NULL;
 			return TRUE;
 		}
 		infd = open (temporary_file, O_RDONLY);
@@ -704,7 +716,7 @@ gimme_file (const char *filename)
 			return FALSE;
 		}
 
-		outfd = open (filename, O_CREAT|O_TRUNC|O_WRONLY, 0644);
+		outfd = open (filename, O_CREAT|O_TRUNC|O_WRONLY, 0600);
 		if (outfd < 0) {
 			GtkWidget *dialog;
 			dialog = gtk_message_dialog_new
@@ -715,7 +727,7 @@ gimme_file (const char *filename)
 				 _("Unable to create the file:\n"
 				   "\"%s\"\n"
 				   "Please check your permissions of "
-				   "the parent directory"), filename);
+				   "the parent directory"), filename ? filename : "(null)");
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 			close (infd);
@@ -734,7 +746,7 @@ gimme_file (const char *filename)
 					 GTK_MESSAGE_ERROR,
 					 GTK_BUTTONS_OK,
 					 _("Not enough room to write file %s"),
-					 filename);
+					 filename ? filename : "(null)");
 				gtk_dialog_run (GTK_DIALOG (dialog));
 				gtk_widget_destroy (dialog);
 				return FALSE;
@@ -810,6 +822,37 @@ on_cancel_button_clicked (GtkWidget *widget, gpointer data)
 	gtk_main_quit ();
 }
 
+void
+on_help_button_clicked (GtkWidget *widget, gpointer data) 
+{
+	
+	GError *error = NULL;
+
+        gnome_help_display_desktop (NULL, "user-guide", 
+				    "wgoeditmainmenu.xml", "goseditmainmenu-51", 
+				    &error);
+	
+	if (error) {
+		GtkWidget *dialog;
+
+                dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
+                        GTK_DIALOG_DESTROY_WITH_PARENT,
+                        GTK_MESSAGE_ERROR,
+                        GTK_BUTTONS_CLOSE,
+                        _("There was an error displaying help: \n%s"),
+                        error->message);
+
+                g_signal_connect (G_OBJECT (dialog),
+                        "response",
+                        G_CALLBACK (gtk_widget_destroy), NULL);
+                gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+                gtk_widget_show (dialog);
+                g_error_free (error);
+
+        }
+
+}
+
 int
 on_toplevel_key_press_event (GtkWidget *widget,
 			     GdkEventKey *key)
@@ -1062,11 +1105,11 @@ main (int argc, char *argv[])
 	else
 		take_screen_shot ();
 
-	if (g_file_test ("gnome-panel-screenshot.glade2", G_FILE_TEST_EXISTS)) {
-		xml = glade_xml_new ("gnome-panel-screenshot.glade2", NULL, NULL);
+	if (g_file_test ("gnome-panel-screenshot.glade", G_FILE_TEST_EXISTS)) {
+		xml = glade_xml_new ("gnome-panel-screenshot.glade", NULL, NULL);
 	}
 	if (xml == NULL) {
-		xml = glade_xml_new (GLADEDIR "/gnome-panel-screenshot.glade2",
+		xml = glade_xml_new (GLADEDIR "/gnome-panel-screenshot.glade",
 				     NULL, NULL);
 	}
 	if (xml == NULL) {
