@@ -73,11 +73,6 @@ static void panel_widget_style_set      (GtkWidget        *widget,
 					 GtkStyle         *previous_style);
 static void panel_widget_realize        (GtkWidget        *widget);
 
-static gboolean panel_widget_focus_in_event (GtkWidget        *widget,
-					     GdkEventFocus    *event);
-static gboolean panel_widget_focus_out_event(GtkWidget        *widget,
-					     GdkEventFocus    *event);
-
 static void panel_widget_push_move_applet   (PanelWidget      *panel,
                                              GtkDirectionType  dir);
 static void panel_widget_switch_move_applet (PanelWidget      *panel,
@@ -87,6 +82,7 @@ static void panel_widget_free_move_applet   (PanelWidget      *panel,
 static void panel_widget_tab_move           (PanelWidget      *panel,
                                              gboolean          next);
 static void panel_widget_end_move           (PanelWidget      *panel);
+static gboolean panel_widget_popup_panel_menu   (PanelWidget      *panel);
 static gboolean panel_widget_real_focus     (GtkWidget        *widget,
                                              GtkDirectionType  direction);
 
@@ -172,12 +168,12 @@ enum {
 	APPLET_ADDED_SIGNAL,
 	APPLET_REMOVED_SIGNAL,
 	BACK_CHANGE_SIGNAL,
-	APPLET_ABOUT_TO_DIE_SIGNAL,
 	PUSH_MOVE_SIGNAL,
 	SWITCH_MOVE_SIGNAL,
 	FREE_MOVE_SIGNAL,
 	TAB_MOVE_SIGNAL,
 	END_MOVE_SIGNAL,
+	POPUP_PANEL_MENU_SIGNAL,
 	LAST_SIGNAL
 };
 
@@ -341,6 +337,9 @@ panel_widget_class_init (PanelWidgetClass *class)
 	GObjectClass *gobject_class = (GObjectClass*) class;
 	GtkWidgetClass *widget_class = (GtkWidgetClass*) class;
 	GtkContainerClass *container_class = (GtkContainerClass*) class;
+	GtkBindingSet *binding_set;
+
+	binding_set = gtk_binding_set_by_class (class);
 
 	panel_widget_signals[ORIENT_CHANGE_SIGNAL] =
                 g_signal_new ("orient_change",
@@ -349,10 +348,9 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, orient_change),
                               NULL,
                               NULL, 
-                              g_cclosure_marshal_VOID__ENUM,
+                              panel_marshal_VOID__VOID,
                               G_TYPE_NONE,
-                              1,
-                              GTK_TYPE_ORIENTATION); 
+                              0);
 
 	panel_widget_signals[SIZE_CHANGE_SIGNAL] =
                 g_signal_new ("size_change",
@@ -361,10 +359,9 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, size_change),
                               NULL,
                               NULL, 
-                              panel_marshal_VOID__INT,
+                              panel_marshal_VOID__VOID,
                               G_TYPE_NONE,
-                              1,
-                              G_TYPE_INT); 
+                              0);
 
 	panel_widget_signals[APPLET_MOVE_SIGNAL] =
                 g_signal_new ("applet_move",
@@ -409,24 +406,9 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, back_change),
                               NULL,
                               NULL, 
-                              g_cclosure_marshal_VOID__ENUM,
+                              panel_marshal_VOID__VOID,
                               G_TYPE_NONE,
-                              3,
-			      PANEL_TYPE_PANEL_BACK_TYPE,
-			      G_TYPE_POINTER,
-			      G_TYPE_POINTER);
-
-	panel_widget_signals[APPLET_ABOUT_TO_DIE_SIGNAL] =
-                g_signal_new ("applet_about_to_die",
-                              G_TYPE_FROM_CLASS (object_class),
-                              G_SIGNAL_RUN_LAST,
-                              G_STRUCT_OFFSET (PanelWidgetClass, applet_about_to_die),
-                              NULL,
-                              NULL, 
-                              panel_marshal_VOID__POINTER,
-                              G_TYPE_NONE,
-                              1,
-                              G_TYPE_POINTER); 
+                              0);
 
 	panel_widget_signals[PUSH_MOVE_SIGNAL] =
 		g_signal_new ("push_move",
@@ -487,18 +469,29 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_TYPE_NONE,
                               0);
 
+	panel_widget_signals[POPUP_PANEL_MENU_SIGNAL] =
+		g_signal_new ("popup_panel_menu",
+                              G_TYPE_FROM_CLASS (class),
+                              G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+                              G_STRUCT_OFFSET (PanelWidgetClass, popup_panel_menu),
+                              NULL,
+                              NULL,
+                              panel_marshal_BOOLEAN__VOID,
+                              G_TYPE_BOOLEAN,
+                              0);
+
 	class->orient_change = NULL;
 	class->size_change = NULL;
 	class->applet_move = NULL;
 	class->applet_added = NULL;
 	class->applet_removed = NULL;
 	class->back_change = NULL;
-	class->applet_about_to_die = NULL;
 	class->push_move = panel_widget_push_move_applet;
 	class->switch_move = panel_widget_switch_move_applet;
 	class->free_move = panel_widget_free_move_applet;
 	class->tab_move = panel_widget_tab_move;
 	class->end_move = panel_widget_end_move;
+	class->popup_panel_menu = panel_widget_popup_panel_menu;
 
 	object_class->destroy = panel_widget_destroy;
 	gobject_class->finalize = panel_widget_finalize;
@@ -508,12 +501,13 @@ panel_widget_class_init (PanelWidgetClass *class)
 	widget_class->realize = panel_widget_realize;
 	widget_class->expose_event = panel_widget_expose;
 	widget_class->style_set = panel_widget_style_set;
-	widget_class->focus_in_event = panel_widget_focus_in_event;
-	widget_class->focus_out_event = panel_widget_focus_out_event;
 	widget_class->focus = panel_widget_real_focus;
 
 	container_class->add = panel_widget_cadd;
 	container_class->remove = panel_widget_cremove;
+
+	gtk_binding_entry_add_signal (binding_set, GDK_F10, GDK_CONTROL_MASK,
+				      "popup_panel_menu", 0);
 }
 
 static void
@@ -593,15 +587,33 @@ panel_widget_reset_focus (GtkContainer *container,
 	PanelWidget *panel = PANEL_WIDGET (container);
 
 	if (container->focus_child == widget) {
-		GtkWidget *panelw = panel->panel_parent;
-		gboolean return_val;
+		GList *l;
 
-		g_signal_emit_by_name (panelw, "focus",
-				       GTK_DIR_TAB_FORWARD,
-				       &return_val);
-		if (!gtk_window_get_focus (GTK_WINDOW (panelw))) {
-			panel_widget_focus (panel);	
-		}
+		l = gtk_container_get_children (container);
+		if (l && l->next) { /* More than one element on the list */
+			/* There are still object on the panel */
+			for (; l; l = l->next) {
+				GtkWidget *child_widget;
+
+				child_widget = l->data;
+				if (child_widget == widget)
+					break;
+			}
+			if (l) {
+				GtkWidget *next_widget;
+
+				if (l->next)
+					next_widget = l->next->data;
+				else
+					next_widget = l->prev->data;
+
+				gtk_widget_child_focus (next_widget,
+						        GTK_DIR_TAB_FORWARD);
+			}
+		} else
+			panel_widget_focus (panel);
+
+		g_list_free (l);
 	}
 }
 
@@ -639,14 +651,6 @@ panel_widget_cremove (GtkContainer *container, GtkWidget *widget)
 	p = g_object_get_data (G_OBJECT (widget),
 				 PANEL_APPLET_ASSOC_PANEL_KEY);
 
-	if (ad != NULL &&
-	    ad->no_die == 0) {
-		g_signal_emit (G_OBJECT (container),
-			       panel_widget_signals[APPLET_ABOUT_TO_DIE_SIGNAL],
-			       0, widget);
-	}
-
-
 	if (p != NULL)
 		run_up_forbidden (p, remove_panel_from_forbidden);
 
@@ -709,7 +713,7 @@ panel_widget_is_applet_stuck(PanelWidget *panel, GtkWidget *applet)
 	list = g_list_find(panel->applet_list,ad);
 
 	g_return_val_if_fail(list!=NULL,FALSE);
-	
+
 	do {
 		i=ad->pos+ad->cells;
 		if(i==panel->size)
@@ -1756,9 +1760,6 @@ panel_widget_finalize (GObject *obj)
 	g_free (panel->unique_id);
 	panel->unique_id = NULL;
 
-	if (panel->key_event)
-		gdk_event_free ((GdkEvent *)panel->key_event);
-
 	if (G_OBJECT_CLASS (panel_widget_parent_class)->finalize)
 		G_OBJECT_CLASS (panel_widget_parent_class)->finalize (obj);
 }
@@ -2085,11 +2086,7 @@ panel_widget_get_cursorloc (PanelWidget *panel)
 
 	gtk_widget_get_pointer (GTK_WIDGET (panel), &x, &y);
 
-	if (panel->orient == GTK_ORIENTATION_HORIZONTAL) {
-		return x;
-	} else {
-		return y;
-	}
+	return panel->orient == GTK_ORIENTATION_HORIZONTAL ? x : y;
 }
 
 /*calculates the value to move the applet by*/
@@ -2297,30 +2294,21 @@ panel_widget_applet_move_to_cursor (PanelWidget *panel)
 			if(panel != new_panel &&
 			   panel_widget_is_cursor(new_panel,10) &&
 			   (!g_slist_find(forb,new_panel))) {
-				pos = panel_widget_get_moveby (new_panel, 0,
-							       ad->drag_off);
-				if (pos < 0)
-					pos = 0;
+				pos = panel_widget_get_moveby (new_panel, 0, ad->drag_off);
+
+				if (pos < 0) pos = 0;
+
 				panel_widget_applet_drag_end (panel);
-				/*disable reentrancy into this
-				  function*/
-				if (panel_widget_reparent (panel,
-							   new_panel,
-							   applet,
-							   pos) == -1) {
-					panel_widget_applet_drag_start
-						(panel, applet, ad->drag_off);
-					/*can't find a free pos
-					  so cancel the reparent*/
+
+				/*disable reentrancy into this function*/
+				if (!panel_widget_reparent (panel, new_panel, applet, pos)) {
+					panel_widget_applet_drag_start (panel, applet, ad->drag_off);
 					continue;
 				}
-				panel_widget_applet_drag_start (new_panel,
-								applet,
-								ad->drag_off);
-				/* schedule a move, the thing might have
-				 * gone outside the cursor, thus we need to
-				 * schedule a move */
-				schedule_try_move(new_panel, TRUE);
+
+				panel_widget_applet_drag_start (new_panel, applet, ad->drag_off);
+				schedule_try_move (new_panel, TRUE);
+
 				return;
 			}
 		}
@@ -2543,10 +2531,6 @@ panel_widget_applet_destroy (GtkWidget *applet, gpointer data)
 	if(applet->parent) {
 		PanelWidget *panel = PANEL_WIDGET (applet->parent);
 
-		g_signal_emit (G_OBJECT (panel),
-			       panel_widget_signals[APPLET_ABOUT_TO_DIE_SIGNAL],
-			       0, applet);
-
 		if (panel->currently_dragged_applet == ad)
 			panel_widget_applet_drag_end (panel);
 
@@ -2746,6 +2730,14 @@ panel_widget_reparent (PanelWidget *old_panel,
 
 	ad = g_object_get_data (G_OBJECT (applet), PANEL_APPLET_DATA);
 	g_return_val_if_fail(ad!=NULL,-1);
+
+	/* Don't try and reparent to an explicitly hidden panel,
+	 * very confusing for the user ...
+	 */
+	if (BASEP_IS_WIDGET (new_panel->panel_parent) &&
+	    (BASEP_WIDGET (new_panel->panel_parent)->state == BASEP_HIDDEN_LEFT ||
+	     BASEP_WIDGET (new_panel->panel_parent)->state == BASEP_HIDDEN_RIGHT))
+		return FALSE;
 	
 	/*we'll resize both panels anyway*/
 	ad->dirty = FALSE;
@@ -2777,7 +2769,7 @@ panel_widget_reparent (PanelWidget *old_panel,
 
 	ad->no_die--;
 
-	return pos;
+	return TRUE;
 }
 
 void
@@ -2813,12 +2805,12 @@ panel_widget_change_params(PanelWidget *panel,
 	if(oldorient != panel->orient) {
 	   	g_signal_emit (G_OBJECT(panel),
 	   		       panel_widget_signals[ORIENT_CHANGE_SIGNAL],
-	   		       0, panel->orient);
+	   		       0);
 	}
 	if(oldsz != panel->sz) {
 	   	g_signal_emit (G_OBJECT(panel),
 	   		       panel_widget_signals[SIZE_CHANGE_SIGNAL],
-	   		       0, panel->sz);
+	   		       0);
 	}
 	if(back_color) {
 		/*this will allways trigger, but so what*/
@@ -2961,7 +2953,6 @@ panel_widget_tab_move (PanelWidget *panel,
 	GSList *li;
 	PanelWidget *new_panel = NULL;
 	PanelWidget *previous_panel = NULL;
-	PanelWidget *first_panel = panels->data;
 
 	ad = panel->currently_dragged_applet;
 
@@ -3006,59 +2997,21 @@ panel_widget_end_move (PanelWidget *panel)
 	panel_widget_applet_drag_end (panel);
 }
 
-static gboolean
-panel_widget_focus_in_event (GtkWidget *widget, GdkEventFocus *event)
-{
-	/*
-	 * FIXME: we need to figure out something sensible
-	 *        to do to indicate focus
-	 */
-
-	GTK_WIDGET_CLASS (panel_widget_parent_class)->focus_in_event (widget, event);
-
-	return FALSE;
-}
-
-static gboolean
-panel_widget_focus_out_event (GtkWidget *widget, GdkEventFocus *event)
-{
-	PanelWidget *panel_widget = PANEL_WIDGET (widget);
-
-	if (GTK_WINDOW (panel_widget->panel_parent)->has_focus)
-		GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
-
-	GTK_WIDGET_CLASS (panel_widget_parent_class)->focus_out_event (widget, event);
-
-	return FALSE;
-}
-
 static gboolean
 panel_widget_real_focus (GtkWidget        *widget,
                          GtkDirectionType  direction)
 {
-	PanelWidget *panel = PANEL_WIDGET (widget);
-
-	if (panel->key_event) {
-		if (panel->key_event->state & GDK_CONTROL_MASK) {
-			/*
-	 		 * Ctrl+Tab was pressed when focus was in applet in
-			 * another process
-			 */
-			panel_widget_focus (PANEL_WIDGET (widget));
-			return TRUE;
-		}
-	}
-
-	if (GTK_WIDGET_HAS_FOCUS (widget)) {
+	if (GTK_WIDGET_HAS_FOCUS (widget) && GTK_FIXED (widget)->children) {
 		GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
 	}
 	return GTK_WIDGET_CLASS (panel_widget_parent_class)->focus (widget, direction);
 }
 
-void panel_widget_focus (PanelWidget *panel)
+void 
+panel_widget_focus (PanelWidget *panel)
 {
 	/*
-	 * Set the focus back on the panel; we unset the focus child so that
+         * Set the focus back on the panel; we unset the focus child so that
 	 * the next time focus is inside the panel we do not remember the
 	 * previously focused child. We also need to set GTK_CAN_FOCUS flag
 	 * on the panel as it is unset when this function is called.
@@ -3066,10 +3019,11 @@ void panel_widget_focus (PanelWidget *panel)
 	if (!DRAWER_IS_WIDGET (panel->panel_parent)) {
 		gtk_container_set_focus_child (GTK_CONTAINER (panel), NULL);
 		GTK_WIDGET_SET_FLAGS (panel, GTK_CAN_FOCUS);
-      		gtk_widget_grab_focus (GTK_WIDGET (panel));
+		gtk_widget_grab_focus (GTK_WIDGET (panel));
 	}
 }
 
+
 PanelOrient
 panel_widget_get_applet_orient (PanelWidget *panel)
 {
@@ -3082,13 +3036,11 @@ panel_widget_get_applet_orient (PanelWidget *panel)
 	return basep_widget_get_applet_orient (BASEP_WIDGET (panel->panel_parent));
 }
 
-void 
-panel_widget_save_key_event (PanelWidget *panel,
-			     GdkEventKey *key_event)
+static gboolean 
+panel_widget_popup_panel_menu (PanelWidget *panel)
 {
-	if (panel->key_event) {
-		gdk_event_free ((GdkEvent *)panel->key_event);
-	}
-	panel->key_event = (GdkEventKey *) gdk_event_copy ((GdkEvent *)key_event);
-}
+	gboolean ret_val;
 
+	g_signal_emit_by_name (panel, "popup_menu", &ret_val);
+	return ret_val;
+}
